HarborBuoySide enum

Which side of its anchor an anchored buoy sits on. start and end are in reading order, as in AlignmentDirectional.centerStart: start is on the right under right-to-left.

Inheritance
Available extensions

Values

above → const HarborBuoySide
below → const HarborBuoySide
start → const HarborBuoySide
end → const HarborBuoySide

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

after → const HarborBuoySide
before → const HarborBuoySide
values → const List<HarborBuoySide>
A constant List of the values in this enum, in order of their declaration.