HarborLayoutRecord class

The dock positions and clearances a harbor laid out last, in its own coordinates.

Annotations

Constructors

HarborLayoutRecord({required Rect frame, required Rect body, required Rect clearWater, required List<HarborDockRecord> docks, required EdgeInsetsDirectional obstruction, required double tide})
const

Properties

body → Rect
final
clearWater → Rect
final
docks → List<HarborDockRecord>
final
frame → Rect
final
hashCode → int
The hash code for this object.
no setterinherited
obstruction → EdgeInsetsDirectional
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tide → double
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited